@@ -4,7 +4,8 @@
 #include "macros.h"
 
 #include <gio/gio.h>
-#include <girara/utils.h>
+#include <girara/log.h>
+#include <girara-gtk/utils.h>
 #include <glib.h>
 #include <magic.h>
 #include <stdio.h>
@@ -108,17 +109,13 @@ static char* guess_type_glib(const char* path) {
   return NULL;
 }
 
-static int compare_content_types(const void* lhs, const void* rhs) {
-  return g_strcmp0(lhs, rhs);
-}
-
 char* zathura_content_type_guess(zathura_content_type_context_t* context, const char* path,
                                  const girara_list_t* supported_content_types) {
   /* try libmagic first */
   char* content_type = guess_type_magic(context, path);
   if (content_type != NULL) {
     if (supported_content_types == NULL ||
-        girara_list_find(supported_content_types, compare_content_types, content_type) != NULL) {
+        girara_list_find(supported_content_types, girara_list_cmpstr, content_type) != NULL) {
       return content_type;
     }
     girara_debug("content type '%s' not supported, trying again", content_type);
@@ -128,7 +125,7 @@ char* zathura_content_type_guess(zathura_content_type_context_t* context, const
   content_type = guess_type_glib(path);
   if (content_type != NULL) {
     if (supported_content_types == NULL ||
-        girara_list_find(supported_content_types, compare_content_types, content_type) != NULL) {
+        girara_list_find(supported_content_types, girara_list_cmpstr, content_type) != NULL) {
       return content_type;
     }
     girara_debug("content type '%s' not supported", content_type);
