@@ -5,6 +5,8 @@
 
 #include "types.h"
 
+#include <gtk/gtk.h>
+
 /**
  * Creates a new zathura link
  *
@@ -13,9 +15,8 @@
  * @param target Target
  * @return New zathura link
  */
-ZATHURA_PLUGIN_API zathura_link_t*
-zathura_link_new(zathura_link_type_t type, zathura_rectangle_t position,
-    zathura_link_target_t target);
+ZATHURA_PLUGIN_API zathura_link_t* zathura_link_new(zathura_link_type_t type, zathura_rectangle_t position,
+                                                    zathura_link_target_t target);
 
 /**
  * Free link
@@ -64,4 +65,13 @@ void zathura_link_evaluate(zathura_t* zathura, zathura_link_t* link);
  */
 void zathura_link_display(zathura_t* zathura, zathura_link_t* link);
 
+/**
+ * Copy a link into the clipboard using and display it using girara_notify
+ *
+ * @param zathura Zathura instance
+ * @param link The link
+ * @param selection target clipboard
+ */
+void zathura_link_copy(zathura_t* zathura, zathura_link_t* link, GdkAtom* selection);
+
 #endif // LINK_H
